@@ -59,7 +59,12 @@ def run(moduleName, **parDict):
     exec(f"import {moduleName}")
     module = eval(moduleName)
     try:
-        module.run(**parDict)
+        for k, v in parDict.items():
+            if hasattr(module, k):
+                setattr(module, k, v)
+            else:
+                b.warning(f"模块缺少属性定义 module={moduleName} k={k} v={v}")
+        module.run()
     except Exception as e:
         raise e
     finally:
